%  get_comps   MATLAB function
%  estimates the components to plot and the number of axes 
%  needed ( = # of channels toggled on in checkboxes, max = 5)
%  Called by load_TS to initialize axes, then called by plot_TS for
%  every new plot. If the number of channels to plot has changed,
%  get_comps calls setup_ax to re-adjust # of axes.
%  Input # of axes.
%  Returns array of components to plot (nsites x nchan) and # of axes.

function [comps,naxes] = get_comps(NAXES)


comps = zeros(3,5);
for k = 1:3
   for l = 1:5
      c_temp = ['UseDat(',num2str(k),',',num2str(l),')'];
      comps(k,l) = get(findobj('Tag',c_temp),'Value');
   end
end
naxes = size(find(sum(comps)),2);
%  if the number of axes has changed (because the user has toggled channels
%  NAXES is the # of axes from the previous current plot, naxes is the 
%  estimated # of axes from the current settings) call setup_ax to create
%  new set of axes.
if (naxes ~= NAXES)
   %  delete current axes
   for k = 1:NAXES
      delete(gca);
   end
   setup_ax(naxes);
end
return