%	head_EGB   MATLAB function 
% 	
%	reads information from header files: Start time, sampling
%	rate and # of channels. Returns header structure containing
%	start time # of channels and sampling rate.

%	USAGE: [header] = head_EGB(cfile,k)
%

function [header] = head_egb(cfile,k)
global fid_bin
global sc_factor

    charfile = char(cfile(k))
    ll = findstr(charcfile,'.');
    cfile_head = [charfile(1:ll),'e99'];
    fid = fopen(cfile_head,'r');
    %  open the binary files here 
    cf = [charfile(1:ll),'egb'];
    fid_bin(k) = fopen(cf,'r','l');
    
    ctemp = fgets(fid);
    %		find DELTA_T (sampling rate in s)
    while (isempty(findstr((ctemp),'Sequ.Clock')))
       ctemp = fgets(fid);
    end
    dt = str2num(ctemp(12:19));
    
    %		find NCHAN
    while (isempty(findstr((ctemp),'Channels')))
      ctemp = fgets(fid);
    end
    nch = 1;
       for n = 10:length(ctemp)
       if (str2num(ctemp(n)) > nch) 
          nch = str2num(ctemp(n));
       end
    end
    
    %		find scale factors
    while (isempty(findstr((ctemp),'K CMP')))
      ctemp = fgets(fid);
    end
    for n = 1:8
       ctemp = fgets(fid);
       if (ctemp(3:3) == 'E') 
          amp = str2num(ctemp(22:26)); % telluric amplification
          tel = str2num(ctemp(32:37)); % telluric length
          sc_factor(k,n) = (10000/2^16)/(amp*tel/1000);
       elseif (ctemp(3:3) == 'B')
          sfm = str2num(ctemp(11:16)); % scale factor mantissa
          sfe = str2num(ctemp(18:20)); % scale factor exponent
          sc_factor(k,n) = (10000/2^16)*sfm*10^sfe;
       end
    end   
       
    %    find START TIME
    while (isempty(findstr((ctemp),'Start')))
      ctemp = fgets(fid);
    end
    b(1) = str2num(ctemp(19:20));
    b(2) = str2num(ctemp(16:17));
    b(3) = str2num(ctemp(13:14));
    b(4) = str2num(ctemp(22:23));
    b(5) = str2num(ctemp(25:26));
    b(6) = str2num(ctemp(28:29));
    %    find STOP TIME
    while (isempty(findstr((ctemp),'Stop')))
      ctemp = fgets(fid);
    end
    c(1) = str2num(ctemp(19:20));
    c(2) = str2num(ctemp(16:17));
    c(3) = str2num(ctemp(13:14));
    c(4) = str2num(ctemp(22:23));
    c(5) = str2num(ctemp(25:26));
    c(6) = str2num(ctemp(28:29));
    
    %    find Number of Blocks (*60 = Number of Samples)
    while (isempty(findstr((ctemp),'Last')))
      ctemp = fgets(fid);
    end
    nsamples = str2num(ctemp(25:29)) * 60;
    
 %  put into structure
    header = struct('start_year',b(1),'start_mon',b(2),'start_day',b(3),...
                    'start_hr',b(4),'start_min',b(5),'start_sec',b(6),...
                    'stop_year',c(1),'stop_mon',c(2),'stop_day',c(3),...
                    'stop_hr',c(4),'stop_min',c(5),'stop_sec',c(6),..
                    'dt',dt,'nch',nch,'nsamples',nsamples);  
    
    fclose(fid);

  return
  
