%	head_mtu   MATLAB function 
% 	
%	reads information from the Phoenix header files: Start time, 
%  sampling rate and # of channels. Returns header structure 
%  containing start time # of channels and sampling rate tsl.
% caution: start & stop times in header (*.tbl) may not be 
%          time of actual end of recording!
%          --> read first and last tag in tsl/tsh (=bin)-file
%	USAGE: [header] = head_mtu(cfile,k)
%

function [header] = head_mtu(cfile,k)

  global fid_bin sc_factor
  global l3ns l4ns hsmp
  global format ext
  global head
  
    l3ns(k) = 0;
    l4ns(k) = 0;
    hsmp(k) = 0;
   
    charfile = char(cfile(k))
    ll = findstr(charfile,'.');
    %   open the header file
    cfile_head = [charfile(1:ll-1),'.tbl'];
    fid = fopen(cfile_head,'r','ieee-le');
    if fid < 0
        ll = max(find(charfile == '/'))
        cfile_head = [charfile(1:ll),'startup.tbl']
        fid = fopen(cfile_head,'r','ieee-le');
        if fid < 0
            Warning=['No startup .tbl file found']
            return
        end
    end
    
    %  	open the data file 
    fid_bin(k) = fopen(charfile,'r','ieee-le');
    %   determine tag length (16 or 32)
    fseek(fid_bin(k),0,-1);
    tag = fread(fid_bin(k),16,'uint8');
    tsize = tag(14); if (tsize == 0) tsize = 16; end;

    %	find line frequency
    [pos,ctemp] = find_tag_tbl(fid,'LFRQ',1);
    lf = ctemp(13:13);
    
    %   find dt (sampling rate in s)
    %   tsl/tsh files -> from tbl file,
    %   tsn files -> from data file.
    [pos,ctemp] = find_tag_tbl(fid,'V5SR',1);
    dt_index = ctemp(13:13);
    if (char(ext(k,1:3)) == 'tsl')
         if (dt_index == 0)
       	    dt = 1/15;
         elseif (dt_index == 1)
            dt = 1/24;
         end
     elseif (char(ext(k,1:3)) == 'tsh')     
         if (dt_index == 0)
             f = [300,2400];
         elseif (dt_index == 1 & lf == 50)
             f = [320,2560];
         elseif (dt_index == 1 & lf == 60)
             f = [384,3072];
         end
    	 % filename GUI
	 	 prompt = {strcat('Select frequency: 1=',num2str(f(1)),' Hz,   2=',num2str(f(2)),' Hz')};
         title  = 'Choose frequency';
    	 lines  = 1;
         def = {'1'};
         %if (k == 1)
            ifreq = str2num(char(inputdlg(prompt,title,lines,def)));
            dt = 1/f(ifreq);
         %end
    elseif ((char(ext(k,1:3)) == 'ts2' | char(ext(k,1:3)) == 'ts3' | char(ext(k,1:3)) == 'ts4' | ...
             char(ext(k,1:3)) == 'ts5') & tsize == 32) 
        fseek(fid_bin(k),0,-1);
        tag = fread(fid_bin(k),32,'uint8');
        dt = (tag(20)*256+tag(19))^-1;
        % cycles per minute
        if (tag(21)==1) dt = dt*60; end;
        % cycles per hour
        if (tag(21)==2) dt = dt*3600; end;
        % cycles per day
        if (tag(21)==3) dt = dt*3600*24; end;
    end
    
    %   seconds of contiguous Level3 acquisition (tsh, also: tsn)
    [pos,ctemp] = find_tag_tbl(fid,'L3NS',1);
    fseek(fid,-13,0);
    l3ns(k) = fread(fid,1,'int');
    %   seconds of contiguous Level4 acquisition
    [pos,ctemp] = find_tag_tbl(fid,'L4NS',1);
    fseek(fid,-13,0);
    l4ns(k) = fread(fid,1,'int');
    %   set NSeconds field in GUI
    if (dt <= 1/1000)
        set(findobj('Tag','NSeconds'),'String',num2str(l3ns(1)));
    elseif (dt > 1/1000 & char(ext(k,1:3)) == 'tsh')
        set(findobj('Tag','NSeconds'),'String',num2str(l4ns(1)));
    end
    %   lh sample interval in minutes: L4: 0 min, L3: hsmp*min, L4: 2*hsmp*min...
    [pos,ctemp] = find_tag_tbl(fid,'HSMP',1);
    fseek(fid,-13,0);
    hsmp(k) = fread(fid,1,'int');
    %   not sure why ts3 data from ministik has hsmp=1800
    %   -> its actually one hour! maybe:
    %   seconds instead of minutes; times two due to l4ns = 0!
    if (char(ext(k,1:3)) == 'ts2' | char(ext(k,1:3)) == 'ts3') 
        hsmp(k) = hsmp(k)/60;
        % factor 2, but we don't correct! -> easier!
        % if (l4ns == 0) hsmp(k) = 2*hsmp(k); end;
    end

    %	find the start & stop time of data from header
    [pos,ctemp] = find_tag_tbl(fid,'STIM',1);
    start = ctemp(13:18);
    [pos,ctemp] = find_tag_tbl(fid,'ETIM',1);
   	stop = ctemp(13:18);
    % = user defined start & stop time, 
    % wanted: stop time of data acquisition! see below...
       
    %   find channels and find scale factors
    CHXX = ['CHHX';'CHHY';'CHHZ';'CHEX';'CHEY'];
    for ichan=1:5
        [pos,ctemp] = find_tag_tbl(fid,CHXX(ichan,:),1);
        flag_chan(ichan) = ctemp(13:13);
        
        [pos,ctemp] = find_tag_tbl(fid,'HNOM',1);
       	sc_factor(k,ichan) = 0;
       	if (ichan<=3 & flag_chan(ichan)>0)
            [pos,ctemp] = find_tag_tbl(fid,'HNOM',1);
            fseek(fid,-13,0);
            hgain = fread(fid,1,'float64'); % magnetic nominal gain mV/nT
            if (char(ext(k,1:3)) ~= 'tsh' & char(ext(k,1:3)) ~= 'tsl')
                [pos,ctemp] = find_tag_tbl(fid,'HGNC',1);
                if pos~=0
                    fseek(fid,-13,0);
                    bamp = fread(fid,1,'int32')% magnetic base amplification (?? -> 1, neutral...)
                    [pos,ctemp] = find_tag_tbl(fid,'HGN',2); bamp=1;
                else
                    [pos,ctemp] = find_tag_tbl(fid,'HGN',1); bamp=1;
                end
            else
                [pos,ctemp] = find_tag_tbl(fid,'HGNC',1);
                if pos~=0
                    fseek(fid,-13,0);
                    bamp = fread(fid,1,'int32')% magnetic base amplification (?? -> 1, neutral...)
                    if bamp==0 bamp=2; end % to be checked: zero for 1566 (mtu-5a, ministik)
                    % bamp = 1;
                    [pos,ctemp] = find_tag_tbl(fid,'HGN',2);
                else
                    [pos,ctemp] = find_tag_tbl(fid,'HGN',1); bamp=1;
                end
            end
            fseek(fid,-13,0); 
            amp = double(fread(fid,1,'int32'))% amplification
            % below: the three is arbitrary (unclear also: bamp & hgain)
            sc_factor(k,ichan) = (2*10000/2^24)/(hgain*bamp*amp);
            %sc_factor(k,ichan) = (10000/2^24)/(hgain*bamp*amp);
         elseif (ichan>=4 & flag_chan(ichan)>0)
    	    ELN = ['EXLN';'EYLN'];
            [pos,ctemp] = find_tag_tbl(fid,ELN(ichan-3,:),1);
         	fseek(fid,-13,0);
         	tel = fread(fid,1,'float64');% telluric line length
            if (char(ext(k,1:3)) ~= 'tsh' & char(ext(k,1:3)) ~= 'tsl')
                [pos,ctemp] = find_tag_tbl(fid,'EGNC',1);
                if pos~=0
                    fseek(fid,-13,0);
                    bamp = fread(fid,1,'int32')% telluric base amplification (?? -> 2, looks good...)
                    [pos,ctemp] = find_tag_tbl(fid,'EGN',2);
                else
                    [pos,ctemp] = find_tag_tbl(fid,'EGN',1); bamp=1;
                end
            else
                [pos,ctemp] = find_tag_tbl(fid,'EGNC',1);
                if pos~=0
                    fseek(fid,-13,0);
                    bamp = fread(fid,1,'int32')% telluric base amplification (?? -> 2, looks good...)
                    %bamp=2% looks better!!!
                    if bamp==0 bamp=2; end % to be checked: zero for 1566 (mtu-5a, ministik)
                    %bamp = 2; % assumed - telluric base amplification (?? -> 2, looks good...)
                    [pos,ctemp] = find_tag_tbl(fid,'EGN',2);
                else
                    [pos,ctemp] = find_tag_tbl(fid,'EGN',1); bamp=1;
                end
            end
            fseek(fid,-13,0);
            amp = fread(fid,1,'int32')%  amplification
            if (amp==10) amp=8; end
            sc_factor(k,ichan) = -(10000/2^24)/(bamp*amp*tel/1000);
            % olny ministik test:
            %if (ichan==4) sc_factor(k,ichan) = 50/87*sc_factor(k,ichan); end;
            %if (ichan==5) sc_factor(k,ichan) = 50/107*sc_factor(k,ichan); end;            
        end
    end
    nch = size(find(flag_chan),2);
    
    % find start time of data aqucisition from data file
    fseek(fid_bin(k),0,-1);
    tag = fread(fid_bin(k),tsize,'uint8');
	start = tag(1:6)'
    
    % find stop time of data aqucisition from data file
    if (char(ext(k,1:3)) == 'tsh')
        fseek(fid_bin(k),-(3*nch*f(1)+tsize),1);
      	tag  = fread(fid_bin(k),tsize,'uint8');
      	stop = tag(1:6)';
	    if (~((stop(4)>=1 & stop(4)<=24) & (stop(5)>=1 & stop(5)<=12)))
	  	 	fseek(fid_bin(k),-(3*nch*f(2)+16),1);
       		tag = fread(fid_bin(k),tsize,'uint8');
        	stop = tag(1:6)';
        end
    else 
        fseek(fid_bin(k),round(-(3*nch/dt+tsize)),1);
    	tag = fread(fid_bin(k),tsize,'uint8');
	  	stop = tag(1:6)'
    end

    %% store data in structure
    header = struct('start_year',start(6),'start_mon',start(5),'start_day',start(4),...
                     'start_hr',start(3),'start_min',start(2),'start_sec',start(1),...
                     'stop_year',stop(6),'stop_mon',stop(5),'stop_day',stop(4),...
                     'stop_hr',stop(3),'stop_min',stop(2),'stop_sec',stop(1),...
                     'dt',dt,'nch',nch);  %  put into structure
    fclose(fid);
 
  return
  
  %------------------------------------------------
  function [pos,ctemp] = find_tag_tbl(fid,tag,inum)
  
  % positions (pos) tbl file (fid) to certain tag (tag, ctemp)
  % at its inum' occurrence in file.
  fseek(fid,0,-1);
  ctemp = fread(fid,25,'uint8');
  n = 0;
  while (isempty(findstr(char(ctemp'),tag)) | n~=inum);
      ctemp = fread(fid,25,'uint8');
      if (~ isempty(findstr(char(ctemp'),tag))) n=n+1; end;
      if feof(fid) pos=0; disp(['Warning: not found: ',tag]); return; end
  end
  pos = ftell(fid);

  return